function pasteurizer
% By: Tomas Tungen Kjellstrm 
% Start date: 13.03.2017
% NTNU
% Details:
% This function imports the retentate stream (R) based on 
% the raw milk stream (mr) and performes a flash paseurization of 
% the fat, water and lactose regulated milk to remove unvanted residual
% microbes.
if nargin==0
    m_r=100
    ph=5
    pr=4
    pl=1
    x0_cas_end=4   % retentate (main stream) casein mass fraction, w/w %
    P=2;
end
% Importing data from the ultra filtration membrane unit:
 [R, x0_w,x0_lip,x0_lac,x0_min,x0_cas,x0_whey,x0_whey_de,x0_NPN]=UF_filter(m_r, ph, pr, pl,x0_cas_end);

% assumptions:
% the milk heat capacity is equal the water heat capasity, the posterior
% stages are isothermal and the initial temperature of the milk is 7 C.

% Sources:
% {1] Aylward, G., Findlay, T. (2008). SI Chemical Data. Sixth edition.
% Milton, Australia: John Wiley & Sons Australia Ltd 
 
% Forbedrings potensiale:
% Lage en estimerings metode for kontinuerlig oppvarming som beregner tiden
% som trengs for  oppn en bestemt temperatur.
% lage modell med mer enn en komponent.
% Finne en mte  estimere tapsandel som flge av varmebehandlingen


% Initial physical properties:
T_in=7; % C
CP_mol_w=75; % kJ/K kmol [1]
Mw= 18.016; %kg/kmol
CP_w=CP_mol_w/Mw; % kJ/K kg
CP_milk=3.95; % kJ/kg K
rho_milk=1030; % kg/m^3
rho_w=995.8; % kg/m^3
n_w=R/Mw*0.10; % kmol/h water
% Flash pasteurization conditions:
T_out=71.6; % C
t=15; % s

% Saturation temperature of the heating water (Boiling point):
T0=100;% Normal boiling point
% entalpy of vaporation/condensation: d_H_vap ?d_H_sub-d_H_fus
d_H_vap=(50-6)*10^3; % kJ/kmol [1]
T0=100+273.15; % 100 C
%Tlim=T_out+20;
P0=1; %atm
R_g=8.314472; % universal gas constant, kJ/kmol K
Tb=1/(1/T0-R_g*log((P/P0))/d_H_vap); %k
Tb_c=Tb-273.15 % C

% The heat required to reach the extintion temperature: 
H_milk=R*CP_milk*(T_out-T_in)/3600 % kW

n_sec=n_w/3600
%H_water=n_w*(d_H_vap+CP_mol_w*(Tb-Tlim))
T_lim=Tb_c+d_H_vap/CP_mol_w-H_milk/n_sec/CP_mol_w
% Temperature difference of in the hot stream:
d_Th=Tb_c-T_lim;

% Logarithmic mean temperature difference (LMTD):
d_T_m=((Tb_c-T_out)-(T_lim-T_in))/(log((Tb_c-T_out)/(T_lim-T_in)))
% The needed heating time to reach extintion temperature:

% The overall heat transfer coefficient:
% for water the range is 800-1500 W/m^2 s, for organic solvents 100-300
% W/m^2 s
U=800; % W/m^2 C
% Area of the heat transfer, m^2:
A=R*CP_milk*d_Th/d_T_m/(U*10^(-3)*60^2)
end