function [m_fs,x_fs_pro,x_fs_lip,x_fs_lac,x_fs_min,x_fs_w]= sep_mass_balance(m_r)
% By: Tomas Tungen Kjellstrm 
% Start date: 17.02.2017
% NTNU
% Details:
% This function generates the mass balance for the separator, to find the
% amounts of produced cream and skimmed milk with the given feed amount
% m_r (kg/h)

% Assumptions:
% The protein, carbohydrates and salts are completly solved in the water
% and their composition relative to the water content will not be
% altered in this stage

% Importing fractional values of raw milk:
[Lac_r, pro_r, lip_r,min_r,W_r, casein_r, whey]=raw_milk;
% Importing fractional values of wanted production spesifications of cream and simmed milk:
[lip_h, W_h, pro_h, lac_h, min_h, W_s, lip_s, lac_s, pro_s,min_s]=separator;

% Separator balance:
% Find the flow of the high fat stream, by using the water component balance 
% over the separator: m_r*W_r=m_h*W_c+m_s*W_s
m_h=m_r*(W_r-W_s)/(W_h-W_s);
% using the separator mass balance to find the mass flow of skimmed milk:
m_s=m_r-m_h;

% End product balance: surplus high fat cream and fat regulated milk
% the two end product must fullfill the total and component balance:
% m_r= m_fs+m_sur

% Fat regulated milk stream: c_fsc=x_fsf
% m_fs*c_fs=m_s*c_s-m_sur*c_h
% initial splitt factor: m_surplus=(1-A)*m_h
A=0.5; 
tol=1e-7;
maxiter=1e+4;
k=1;
for k=1:maxiter
m_fs=m_s+A*m_h;
lip_fs=(m_s*lip_s+m_h*A*lip_h)/m_fs;
cas_fs=(m_s*(pro_s*0.8)+m_h*A*(pro_h*0.8))/m_fs; % 80 % of milk protein is casein

% Want a fat regulated milk with 1:1 ratio of fat and casein as fat and
% casein content of a cheese is identical to the fat content.
deviation=lip_fs-cas_fs;
% To small split stream:
if deviation>=tol
    diff=-abs(deviation);
% To large split stream:
else
    diff=abs(deviation);
end
if abs(deviation)<=tol || k>=maxiter
    if k>=maxiter
        error('maximum number of iterations reached in the separator mass balance')
    end
    break
end
A=A+diff;
k=k+1;
end
% Fat split stream:
F3=m_h*A;
% Mass fractions of the fat standardized milk: kg/kg
x_fs_pro=cas_fs/0.8;
x_fs_lac=(m_s*lac_s+F3*lac_h)/m_fs;
x_fs_lip=lip_fs;
x_fs_min=(m_s*min_s+F3*min_h)/m_fs;
x_fs_w=(m_s*W_s+F3*W_h)/m_fs;
x_SNF=x_fs_pro+x_fs_lac+x_fs_min;
test_separator=x_fs_pro+x_fs_lac+x_fs_lip+x_fs_min+x_fs_w;
end