function [lip_h, W_h, pro_h, lac_h, min_h, W_s, lip_s, lac_s, pro_s,min_s]=separator
% By: Tomas Tungen Kjellstrm 
% Start date: 18.02.2017
% NTNU
% Details:
% This function contain the mass composition of TINE single cream
% (mat-flte), high fat cream and skimmed milk
% units: kg/kg tot

% Export details:
% abriviations:
% lip= lipids= fat, W= water, pro=protein, min=minerals
% endings:
% h = high fat cream, s= skimmed milk, fs= fat standardized milk

% Refrences:
% [1]
% Bylund, G. (2003). Dairy processing handbook.
% Second edition. Malm, Sweden: Tetra Pak Processing Systems AB

% Assumptions:
% It is assumed that the other components are completely solved 
% in the water and the ratios in the top and bottom of the separator will 
% remain constant to each other than fat.
% relative to fat.

% Importing data from the raw milk function:
[Lac_r, pro_r, lip_r,min_r,W_r, casein_r, whey]=raw_milk;

% water, protein, lactose and mineral ratios:
s=Lac_r+pro_r+min_r+W_r;
R_w=W_r/s; % water
R_p=pro_r/s; % protein
R_lac=Lac_r/s; % lactose
R_min=min_r/s; % minerals

% Single cream:
W_c= 0.733; %water
lip_c= 0.2; % fat
lac_c = 0.039; %lactose
pro_c = 0.027; % protein
casein_c = pro_c*0.8; % casein
whey_c =pro_c*0.2; % whey
salt_c = 0.001; % minerals

% High fat cream (40 w/w %):
lip_h=0.4; % [1]
% i_h=(1-lip_h)*R_i=kg nonfat/kg total*kg i/kg nonfat= kg i/kg total
W_h=(1-lip_h)*R_w;
pro_h=(1-lip_h)*R_p;
lac_h=(1-lip_h)*R_lac;
min_h=(1-lip_h)*R_min;
casein_h=pro_h*0.8;
whey_h=pro_h*0.2;
high_test=lip_h+W_h+pro_h+lac_h+min_h;

% Skimmed milk: 
lip_s=0.05/100; % [1]
W_s=(1-lip_s)*R_w;
pro_s=(1-lip_s)*R_p;
lac_s=(1-lip_s)*R_lac;
min_s=(1-lip_s)*R_min;
casein_s=pro_s*0.8;
whey_s=pro_s*0.2;

skimmed_test=lip_s+W_s+pro_s+lac_s+min_s;
end